@@ -1,6 +1,6 @@
 import pytest
 from tuxmake.runtime import Runtime
-from tuxbake.exceptions import TuxbakeRunCmdError, TuxbakeParsingError
+from tuxbake.exceptions import TuxbakeParsingError
 from pathlib import Path
 import os
 from tuxbake.models import OEBuild
