@@ -1,6 +1,7 @@
 import pytest
 from tuxbake.exceptions import TuxbakeRunCmdError
 import os
+import shutil
 
 
 def test_run_cmd(tmp_path):
@@ -103,3 +104,24 @@ def test_handle_log(capsys, oebuild_git_object):
         with open(f"{src_dir}/fetch.log") as f:
             data = f.readline()
             assert "INFO - Running cmd:" in data
+
+
+def test_copy_artifacts(monkeypatch):
+
+    from tuxbake import utils
+
+    bitbake_env_file = os.path.abspath("tests/unit/bitbake-environment")
+    fake_deploy_dir = os.path.abspath("tests/unit/")
+    monkeypatch.setattr(utils, "find_bitbake_env", lambda a, b: fake_deploy_dir)
+    artifacts_dir = os.path.abspath("tests/unit/test-copy-artifacts-dir")
+    src_dir = fake_deploy_dir
+    artifacts = ["test_utils.py"]
+
+    utils.copy_artifacts(artifacts, src_dir, artifacts_dir, bitbake_env_file)
+
+    assert os.path.exists(artifacts_dir)
+    copied = os.listdir(artifacts_dir)
+    assert len(copied) > 0
+    assert os.path.basename(bitbake_env_file) in copied
+    assert artifacts[0] in copied
+    shutil.rmtree(artifacts_dir)
