@@ -12,7 +12,7 @@ def build(**kwargs):
     try:
         oebuild.prepare()
         oebuild.do_build()
-    except (KeyboardInterrupt, Terminated) as ex:
+    except (KeyboardInterrupt, Terminated):
         print("tuxbake Interrupted")
     if oebuild.artifacts_dir:
         oebuild.publish_artifacts()
