@@ -2,9 +2,10 @@
 
 from tuxbake.exceptions import TuxbakeParsingError
 import re
+from typing import Any
 
 
-def check_instance(value: any, type: any, err_msg) -> None:
+def check_instance(value: Any, type: Any, err_msg) -> None:
     """check the type of arguments"""
     if not isinstance(value, type):
         raise TuxbakeParsingError(err_msg)
