@@ -3,13 +3,25 @@
 import json
 import os
 from dataclasses import asdict, dataclass, field, fields
-from typing import Dict, List
+from typing import Dict, List, Optional
 from tuxmake.runtime import Runtime
 from tuxmake.logging import set_debug, debug
 from tuxbake.utils import repo_init, git_init, copy_artifacts
 from pathlib import Path
 from tuxbake.exceptions import TuxbakeParsingError
-from tuxbake.helper import *
+from tuxbake.helper import (
+    check_instance,
+    validate_artifacts,
+    validate_bblayers_conf,
+    validate_container,
+    validate_environment,
+    validate_extraconfigs,
+    validate_git_dest,
+    validate_git_ref,
+    validate_git_repo,
+    validate_git_sha,
+    validate_local_conf,
+)
 
 
 class Base:
@@ -37,34 +49,34 @@ class Base:
 class OEBuild(Base):
     src_dir: str
     build_dir: str
-    envsetup: str = None
-    targets: List[str] = None
-    extraconfigs: List[str] = None
+    envsetup: Optional[str] = None
+    targets: Optional[List[str]] = None
+    extraconfigs: Optional[List[str]] = None
     extraconfigs_cmd: str = ""
-    distro: str = None
+    distro: Optional[str] = None
     build_only: bool = False
     sync_only: bool = False
-    name: str = None
+    name: Optional[str] = None
     debug: bool = False
-    machine: str = None
-    container: str = None
+    machine: Optional[str] = None
+    container: Optional[str] = None
     environment: Dict = field(default_factory=dict)
-    local_conf: List[str] = None
-    bblayers_conf: List[str] = None
+    local_conf: Optional[List[str]] = None
+    bblayers_conf: Optional[List[str]] = None
     runtime: str = "docker"
-    image: str = None
-    sources: List[Dict] = None
-    sstate_dir: str = None
-    sstate_mirror: str = None
-    dl_dir: str = None
+    image: Optional[str] = None
+    sources: Optional[List[Dict]] = None
+    sstate_dir: Optional[str] = None
+    sstate_mirror: Optional[str] = None
+    dl_dir: Optional[str] = None
     __logger__ = None
-    repo: Dict = None
-    git_trees: List = None
-    local_manifest: str = None
-    pinned_manifest: str = None
+    repo: Optional[Dict] = None
+    git_trees: Optional[List] = None
+    local_manifest: Optional[str] = None
+    pinned_manifest: Optional[str] = None
     # For future use
-    artifacts: List[str] = None
-    artifacts_dir: str = None
+    artifacts: Optional[List[str]] = None
+    artifacts_dir: Optional[str] = None
 
     @dataclass
     class Repo:
@@ -75,10 +87,10 @@ class OEBuild(Base):
     @dataclass
     class Git:
         url: str
-        branch: str = None
-        ref: str = None
-        sha: str = None
-        dest: str = None
+        branch: Optional[str] = None
+        ref: Optional[str] = None
+        sha: Optional[str] = None
+        dest: Optional[str] = None
 
     def __post_init__(self):
         self.log_dir = self.src_dir
