@@ -43,7 +43,7 @@ def repo_init(oebuild, src_dir, local_manifest=None, pinned_manifest=None):
         run_cmd(cmd, src_dir)
 
     if local_manifest:
-        cmd = f"mkdir -p .repo/local_manifests/".split()
+        cmd = "mkdir -p .repo/local_manifests/".split()
         run_cmd(cmd, src_dir)
         cmd = f"cp {local_manifest} .repo/local_manifests/".split()
         run_cmd(cmd, src_dir)
@@ -62,7 +62,7 @@ def git_get_sha(branch, url):
     cmd = f"git ls-remote --exit-code --quiet {url} {branch}".split()
     try:
         ret = run_cmd(cmd, None)
-    except:
+    except TuxbakeRunCmdError:
         raise TuxbakeRunCmdError(f"Unable to fetch the 'branch' or 'ref': {branch}")
     sha = ret.out.split()[0].decode("utf-8")
     return sha
@@ -101,7 +101,7 @@ def git_init(oebuild, src_dir):
         if not dir_repo.exists() and not dir_repo.is_dir():
             cmd = f"mkdir -p {dir_path}".split()
             run_cmd(cmd, src_dir)
-            cmd = f"git init --quiet .".split()
+            cmd = "git init --quiet .".split()
             run_cmd(cmd, os.path.join(src_dir, dir_path))
             cmd = f"git remote add origin {url}".split()
             run_cmd(cmd, os.path.join(src_dir, dir_path))
@@ -124,7 +124,10 @@ def copy_artifacts(artifacts, src_dir, artifacts_dir, bitbake_env_file):
     deploy_dir = find_bitbake_env(bitbake_env_file, "DEPLOY_DIR")
     if deploy_dir:
         if artifacts:
-            dir_paths = [f"{deploy_dir}/{artifact}" for artifact in artifacts]
+            dir_paths = [
+                str(Path(f"{deploy_dir}/{artifact}").resolve())
+                for artifact in artifacts
+            ]
             dirs = " ".join(dir_paths)
         else:
             # whole DEPLOY_DIR to be published
